"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
// Import the CSS
require("../css/widget.css");
// React
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
// Components
const Mito_1 = __importDefault(require("./components/Mito"));
// Logging
const analytics_node_1 = __importDefault(require("analytics-node"));
class ExampleModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign(Object.assign({}, super.defaults()), { _model_name: ExampleModel.model_name, _model_module: ExampleModel.model_module, _model_module_version: ExampleModel.model_module_version, _view_name: ExampleModel.view_name, _view_module: ExampleModel.view_module, _view_module_version: ExampleModel.view_module_version, df_json: '' });
    }
}
exports.ExampleModel = ExampleModel;
ExampleModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
ExampleModel.model_name = 'ExampleModel';
ExampleModel.model_module = version_1.MODULE_NAME;
ExampleModel.model_module_version = version_1.MODULE_VERSION;
ExampleModel.view_name = 'ExampleView'; // Set to null if no view
ExampleModel.view_module = version_1.MODULE_NAME; // Set to null if no view
ExampleModel.view_module_version = version_1.MODULE_VERSION;
class ExampleView extends base_1.DOMWidgetView {
    /*
      We override the DOMWidgetView constructor, so that we can
      create a logging instance for this view.
    */
    initialize(parameters) {
        var _a;
        super.initialize(parameters);
        // Get df name from code block
        (_a = window.commands) === null || _a === void 0 ? void 0 : _a.execute('read_df_name').then((dfName) => {
            var _a;
            // set the data frame name in the model state
            this.model.set('df_name', dfName);
            // set the data frame name in the widget
            (_a = window.Mito) === null || _a === void 0 ? void 0 : _a.setState({ dfName: dfName });
        });
        // We get the user id from the client side
        this.user_id = this.model.get('user_id');
        // Write key taken from segment.com
        this.logger = new analytics_node_1.default('L4FqIZ3qB4C2FBitK4gUn073vv3lyWXm');
        // Identify the user
        this.logger.identify({ userId: this.user_id });
    }
    /*
      We override the sending message utilities, so that we can log all
      outgoing messages
    */
    send(msg) {
        // Log the out-going message
        this.logger.track({
            userId: this.user_id,
            event: 'js_sent_msg_log_event',
            properties: {
                event: msg
            }
        });
        super.send(msg);
    }
    render() {
        // Capture the send, to pass to the component
        const send = (msg) => {
            this.send(msg);
        };
        // TODO: there is a memory leak, in the case where
        // we rerender the component (e.g. we run the mito.sheet)
        // cell again. We need to clean up the component somehow!
        react_dom_1.default.render(react_1.default.createElement(Mito_1.default, { dfName: this.model.get('df_name'), sheetJSON: this.getSheetJSON(), columnSpreadsheetCodeJSON: JSON.parse(this.model.get('column_spreadsheet_code_json')), send: send, ref: (Mito) => { window.Mito = Mito; } }), this.el);
        this.model.on('msg:custom', this.handleMessage, this);
        // Log that this view was rendered
        this.logger.track({
            userId: this.user_id,
            event: 'sheet_view_creation_log_event',
            properties: {}
        });
    }
    getSheetJSON() {
        let sheetJSON = {
            columns: [],
            index: [],
            data: []
        };
        const unparsedSheetJSON = this.model.get('sheet_json');
        try {
            sheetJSON['columns'] = JSON.parse(unparsedSheetJSON)['columns'];
            sheetJSON['index'] = JSON.parse(unparsedSheetJSON)['index'];
            sheetJSON['data'] = JSON.parse(unparsedSheetJSON)['data'];
        }
        catch (e) {
            // Suppress error
        }
        return sheetJSON;
    }
    getCodeJSON() {
        let codeJSON = {
            imports: '# No imports',
            code: ['# No code has been written yet!', 'pass']
        };
        const unparsedCodeJSON = this.model.get('code_json');
        try {
            codeJSON['imports'] = JSON.parse(unparsedCodeJSON)['imports'];
            codeJSON['code'] = JSON.parse(unparsedCodeJSON)['code'];
        }
        catch (e) {
            // Suppress error
        }
        return codeJSON;
    }
    handleMessage(message) {
        /*
          This route handles the messages sent from the Python widget
        */
        var _a;
        // Log that we received this message
        this.logger.track({
            userId: this.user_id,
            event: 'js_recv_msg_log_event',
            properties: {
                event: message
            }
        });
        console.log("Got a message, ", message);
        if (message.event === 'update_sheet') {
            console.log("Updating sheet");
            window.Mito.setState({
                sheetJSON: this.getSheetJSON(),
                columnSpreadsheetCodeJSON: JSON.parse(this.model.get('column_spreadsheet_code_json'))
            });
        }
        else if (message.event === 'update_code') {
            console.log('Updating code.');
            (_a = window.commands) === null || _a === void 0 ? void 0 : _a.execute('write-code-to-cell', { codeJSON: this.getCodeJSON() });
        }
        else if (message.event === 'edit_error') {
            console.log("Updating edit error.");
            window.Mito.setState({ errorJSON: message });
        }
    }
}
exports.ExampleView = ExampleView;
//# sourceMappingURL=widget.js.map